@@ -275,7 +275,7 @@ spGP.Gibbs<-function(formula, data=parent.frame(), time.data, coords,
          stop("\n Error: formula must be specified \n")
     }
   #
-    if (class(formula) != "formula") {
+    if (!inherits(formula, "formula")) {
          stop("\n Error: equation must be in formula-class \n ...")
     }
    #
@@ -1339,7 +1339,7 @@ sptruncated.Gibbs<-function(formula, data=parent.frame(), time.data, coords,
          stop("\n Error: formula must be specified \n")
     }
   #
-    if (class(formula) != "formula") {
+    if (!inherits(formula, "formula")) {
          stop("\n Error: equation must be in formula-class \n ...")
     }
    #
